@@ -71,7 +71,8 @@ class OpenGLResourcePack:
 
     def get_texture_path(self, namespace: Optional[str], relative_path: str):
         """Get the absolute path of the image from the relative components.
-        Useful for getting the id of textures for hard coded textures not connected to a resource pack."""
+        Useful for getting the id of textures for hard coded textures not connected to a resource pack.
+        """
         return self._resource_pack.get_texture_path(namespace, relative_path)
 
     def texture_bounds(self, texture_path: str) -> Tuple[float, float, float, float]:
@@ -106,7 +107,7 @@ class OpenGLResourcePack:
                     os.stat(path).st_mtime
                     for pack in self._resource_pack.pack_paths
                     for path in glob.glob(
-                        os.path.join(pack, "**", "*.*"), recursive=True
+                        os.path.join(glob.escape(pack), "**", "*.*"), recursive=True
                     )
                 ),
                 default=0,
@@ -141,7 +142,7 @@ class OpenGLResourcePack:
                         json.dump((mod_time, bounds), f)
 
             self._image_width, self._image_height = atlas.size
-            self._image = numpy.asarray(atlas, numpy.uint8).ravel()
+            self._image = numpy.array(atlas, numpy.uint8).ravel()
             self._texture_bounds = bounds
 
     def _setup_texture(self, context_id: str):
